@@ -156,6 +156,7 @@ esa <- function (object, sessnum = 1, beta = NULL, real = NULL, noccasions = NUL
 #        print(k)
 #        print(m)
 #        print(nmix)
+#        print(knownclass)
 #        print(summary(trps))
 #        print(usge)
 #        print(summary(mask))
@@ -177,7 +178,8 @@ esa <- function (object, sessnum = 1, beta = NULL, real = NULL, noccasions = NUL
                        as.integer(dettype),
                        as.integer(param),
                        as.double(Xrealparval0),
-                       as.integer(rep(0,n)),                 # dummy groups 2012-11-13, 2013-04-16
+#                       as.integer(rep(0,n)),                 # dummy groups 2012-11-13, 2013-04-16
+                       as.integer(rep(1,n)),      # dummy groups 2012-11-13; 2013-04-16 2013-06-24
                        as.integer(n),
                        as.integer(s),
                        as.integer(k),
