@@ -3,6 +3,7 @@
 ## telemetry.R
 ## fitting detection function to telemetry data
 ## 2012-10-19,20,21,22 2013-06-07
+## 2012-06-15 read.telemetry
 ###############################################################################
 
 distances <- function (X, Y) {
@@ -126,3 +127,83 @@ telemloglik <- function(capthist, traps, mask, detectfn = 0, detectpar) {
     loglik
 }
 ###############################################################################
+
+read.telemetry <- function (file = NULL, data = NULL, noccasions = NULL,
+                          covnames = NULL, verify = TRUE, ...) {
+
+    detector <- 'telemetry'
+    fmt <- 'XY'
+    inflation <- 1e-8
+    nvar <- 5
+
+    if (is.null(data)) {
+        ## input from text file
+        if (is.null(file))
+            stop ("must specify either file or data")
+        dots <- match.call(expand.dots = FALSE)$...
+
+        if (length(file) != 1)
+            stop ("requires single 'file'")
+
+        filetype <- function(x) {
+            nx <- nchar(x)
+            tolower(substring(x, nx-3, nx))
+        }
+
+        countargs <- dots[names(dots) %in% names(formals(count.fields))]
+        if (filetype(file) == '.csv')
+            countargs$sep <- ','
+        countargs$file <- file
+        nfield <- max(do.call(count.fields, countargs))
+        colcl <- c('character','character',NA,NA,NA, rep(NA,nfield-nvar))
+        defaultargs <- list(sep = '', comment.char = '#')
+        if (filetype(file)=='.csv') defaultargs$sep <- ','
+        captargs <- replacedefaults (defaultargs, list(...))
+        captargs <- captargs[names(captargs) %in% names(formals(read.table))]
+        capt <- do.call ('read.table', c(list(file = file, as.is = TRUE,
+        colClasses = colcl), captargs) )
+
+    }
+    else {
+        capt <- data
+    }
+
+    ## let's be clear about this...
+    names(capt)[1:5] <- c('Session','AnimalID','Occ','X','Y')
+    if (any(is.na(capt[,1:nvar])))
+        stop ("missing values not allowed")
+
+    if (!is.null(noccasions))
+        if (noccasions < max(capt$Occ))
+        stop ("file contains occasion number > noccasions")
+
+    readtraps <- function(capt) {
+        ch <- chull(capt[,4:5])
+        ch <- c(ch,ch[1])  ## ensure closed
+        trps <- capt[ch,4:5]
+        ## inflate a tiny bit to ensure all fixes are inside boundary
+        ## the default inflation 1e-8 causes error of 1-(1 + 1e-8)^2 ~ 2e-8
+        trps <- inflate(trps, 1 + inflation)
+        trps <- as.data.frame(trps)
+         dimnames(trps) <- list(1:nrow(trps), c('x','y'))
+        class(trps) <- c('traps', 'data.frame')
+        attr(trps, 'polyID') <- factor(rep(1,nrow(trps)))
+        attr(trps, 'detector') <- 'telemetry'
+        trps
+    }
+
+    splitcapt <- split(capt, capt[,1])
+    trps <- sapply(splitcapt, readtraps, simplify = FALSE)
+    if (length(trps)==1)
+        trps <- trps[[1]]
+    else
+        class(trps) <- c("traps","list")
+
+    temp <- make.capthist(capt, trps, fmt = fmt,  noccasions = noccasions,
+        covnames = covnames, sortrows = TRUE, cutval = NULL,
+        noncapt = 'NONE')
+
+    if (verify)
+        verify(temp)
+    temp
+}
